@@ -1,4 +1,4 @@
-from bolinette_common import logger
+from bolinette.utils import logger
 from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
